cytoflowgui.view_plugins package
================================

Submodules
----------

cytoflowgui.view_plugins.histogram module
-----------------------------------------

.. automodule:: cytoflowgui.view_plugins.histogram
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: cytoflowgui.view_plugins
    :members:
    :undoc-members:
    :show-inheritance:
